@@ -624,14 +624,14 @@ msgstr[1] "Koeie"
         """Tests making a unit with msgidcomments obsolete."""
         posource = '#: first.c\nmsgid ""\n"_: first.c\\n"\n"test"\nmsgstr "rest"\n\n#: second.c\nmsgid ""\n"_: second.c\\n"\n"test"\nmsgstr "rest"'
         poexpected = '#~ msgid ""\n#~ "_: first.c\\n"\n#~ "test"\n#~ msgstr "rest"\n'
-        print("Source:\n%s" % posource)
-        print("Expected:\n%s" % poexpected)
+        print(f"Source:\n{posource}")
+        print(f"Expected:\n{poexpected}")
         pofile = self.poparse(posource)
         unit = pofile.units[0]
         assert not unit.isobsolete()
         unit.makeobsolete()
         assert unit.isobsolete()
-        print("Result:\n%s" % pofile)
+        print(f"Result:\n{pofile}")
         assert str(unit) == poexpected
 
     def test_multiline_obsolete(self):
@@ -1046,6 +1046,42 @@ msgid "test"
 msgstr ""
 "効率的なバグの報告はPostGISの開発を助ける本質的な方法です。最も効率的なバグ報"
 "告は、PostGIS開発者がそれを再現できるようにすることで、それの引き金となったス"
+"""
+        assert self.poreflow(posource) == posource
+
+    @mark.xfail(reason="Incompatible wrapping with gettext, see #5251")
+    def test_wrap_emoji(self):
+        posource = r"""msgid ""
+msgstr "Content-Type: text/plain; charset=utf-8\n"
+
+msgid "test"
+msgstr ""
+"print(ts.string_get_word_breaks(\"Test ❤️‍🔥 Test\")) # Prints [1, 2, 3, 4, 5, "
+"""
+        assert self.poreflow(posource) == posource
+
+    @mark.xfail(reason="Incompatible wrapping with gettext, see #5251")
+    def test_wrap_parenthesis(self):
+        posource = r"""msgid ""
+msgstr "Content-Type: text/plain; charset=utf-8\n"
+
+msgid "test"
+msgstr ""
+"Konvertiert [param what] in [param type] auf die bestmögliche Weise. Der "
+"[param type] verwendet die [enum Variant.Type]-Werte.\n"
+
+msgid "test2"
+msgstr ""
+"- Eine von [Object] abgeleitete Klasse, die in [ClassDB] existiert, z. B. "
+"[Node].\n"
+
+msgid "test3"
+msgstr ""
+"Must be required by a NotificationListenerService, to ensure that only the "
+"system can bind to it. See [url=https://developer.android.com/reference/"
+"android/Manifest."
+"permission#BIND_NOTIFICATION_LISTENER_SERVICE]BIND_NOTIFICATION_LISTENER_SERVICE[/"
+"url]."
 """
         assert self.poreflow(posource) == posource
 
