@@ -1,3 +1,4 @@
+from copy import copy
 from io import BytesIO
 
 from pytest import mark, raises
@@ -171,12 +172,12 @@ class TestPYPOUnit(test_po.TestPOUnit):
             "123456789 123456789 123456789 123456789 123456789 123456789 123456789 1"
         )
         unit = self.UnitClass(str_max)
-        expected = 'msgid "%s"\nmsgstr ""\n' % str_max
+        expected = f'msgid "{str_max}"\nmsgstr ""\n'
         assert str(unit) == expected
         # at this length we wrap
         str_wrap = str_max + "2"
         unit = self.UnitClass(str_wrap)
-        expected = 'msgid ""\n"%s"\nmsgstr ""\n' % str_wrap
+        expected = f'msgid ""\n"{str_wrap}"\nmsgstr ""\n'
         assert str(unit) == expected
 
     def test_wrap_on_newlines(self):
@@ -184,7 +185,7 @@ class TestPYPOUnit(test_po.TestPOUnit):
         string = "123456789\n" * 3
         postring = ('"123456789\\n"\n' * 3)[:-1]
         unit = self.UnitClass(string)
-        expected = 'msgid ""\n%s\nmsgstr ""\n' % postring
+        expected = f'msgid ""\n{postring}\nmsgstr ""\n'
         assert str(unit) == expected
 
         # Now check for long newlines segments
@@ -670,6 +671,31 @@ msgstr ""\r
 
         outstore = self.StoreClass()
         outstore.wrapper.width = -1
-        outstore.addunit(store.units[0])
+        unit = copy(store.units[0])
+        outstore.addunit(unit)
 
         assert max(len(line) for line in bytes(outstore).decode().splitlines()) > 77
+
+        outstore = self.StoreClass()
+        outstore.wrapper.width = -1
+        unit = copy(store.units[0])
+        unit.wrapper = None
+        outstore.addunit(unit)
+
+        assert max(len(line) for line in bytes(outstore).decode().splitlines()) > 77
+
+        outstore = self.StoreClass()
+        outstore.wrapper = None
+        unit = copy(store.units[0])
+        unit.wrapper = None
+        outstore.addunit(unit)
+
+        assert max(len(line) for line in bytes(outstore).decode().splitlines()) <= 77
+
+        outstore = self.StoreClass()
+        outstore.wrapper = None
+        unit = copy(store.units[0])
+        unit.wrapper.width = -1
+        outstore.addunit(unit)
+
+        assert max(len(line) for line in bytes(outstore).decode().splitlines()) <= 77
