@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2009 Zuza Software Foundation
 # Copyright 2013-2014 F Wolff
@@ -23,17 +22,23 @@ Contains the base :class:`StringElem` class that represents a node in a
 parsed rich-string tree. It is the base class of all placeables.
 """
 
+import contextlib
 import logging
-import six
-import sys
+
+
+def filter_all(e):
+    return True
+
+
+def filter_editable(e):
+    return e.iseditable
 
 
 class ElementNotFoundError(ValueError):
     pass
 
 
-@six.python_2_unicode_compatible
-class StringElem(object):
+class StringElem:
     """
     This class represents a sub-tree of a string parsed into a rich structure.
     It is also the base class of all placeables.
@@ -62,12 +67,12 @@ class StringElem(object):
     def __init__(self, sub=None, id=None, rid=None, xid=None, **kwargs):
         if sub is None:
             self.sub = []
-        elif isinstance(sub, (six.text_type, StringElem)):
+        elif isinstance(sub, (str, StringElem)):
             self.sub = [sub]
         else:
             for elem in sub:
-                if not isinstance(elem, (six.text_type, StringElem)):
-                    raise ValueError(elem)
+                if not isinstance(elem, (str, StringElem)):
+                    raise TypeError(elem)
             self.sub = sub
             self.prune()
 
@@ -77,71 +82,72 @@ class StringElem(object):
 
         for key, value in kwargs.items():
             if hasattr(self, key):
-                raise ValueError('attribute already exists: %s' % (key))
+                raise ValueError(f"attribute already exists: {key}")
             setattr(self, key, value)
 
     # SPECIAL METHODS #
     def __add__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self) + rhs
+        return str(self) + rhs
 
     def __contains__(self, item):
         """Emulate the ``unicode`` class."""
-        return item in six.text_type(self)
+        return item in str(self)
 
     def __eq__(self, rhs):
-        """:returns: ``True`` if (and only if) all members as well as sub-trees
+        """
+        :returns: ``True`` if (and only if) all members as well as sub-trees
         are equal. False otherwise.
         """
         if not isinstance(rhs, StringElem):
             return False
 
         return (
-            self.id == rhs.id and
-            self.iseditable == rhs.iseditable and
-            self.istranslatable == rhs.istranslatable and
-            self.isvisible == rhs.isvisible and
-            self.rid == rhs.rid and
-            self.xid == rhs.xid and
-            len(self.sub) == len(rhs.sub) and
-            not [i for i in range(len(self.sub)) if self.sub[i] != rhs.sub[i]])
+            self.id == rhs.id
+            and self.iseditable == rhs.iseditable
+            and self.istranslatable == rhs.istranslatable
+            and self.isvisible == rhs.isvisible
+            and self.rid == rhs.rid
+            and self.xid == rhs.xid
+            and len(self.sub) == len(rhs.sub)
+            and not [i for i in range(len(self.sub)) if self.sub[i] != rhs.sub[i]]
+        )
 
     def __ge__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self) >= rhs
+        return str(self) >= rhs
 
     def __getitem__(self, i):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self)[i]
+        return str(self)[i]
 
     def __getslice__(self, i, j):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self)[i:j]
+        return str(self)[i:j]
 
     def __gt__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self) > rhs
+        return str(self) > rhs
 
     def __iter__(self):
         """Create an iterator of this element's sub-elements."""
-        for elem in self.sub:
-            yield elem
+        yield from self.sub
 
     def __le__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self) <= rhs
+        return str(self) <= rhs
 
     def __len__(self):
         """Emulate the ``unicode`` class."""
-        return len(six.text_type(self))
+        return len(str(self))
 
     def __lt__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self) < rhs
+        return str(self) < rhs
 
     def __mul__(self, rhs):
         """Emulate the ``unicode`` class."""
-        return six.text_type(self) * rhs
+        return str(self) * rhs
 
     def __ne__(self, rhs):
         return not self.__eq__(rhs)
@@ -155,41 +161,43 @@ class StringElem(object):
         return self * lhs
 
     def __repr__(self):
-        elemstr = ', '.join([repr(elem) for elem in self.sub])
-        return '<%(class)s(%(id)s%(rid)s%(xid)s[%(subs)s])>' % {
-            'class': self.__class__.__name__,
-            'id': self.id is not None and 'id="%s" ' % (self.id) or '',
-            'rid': self.rid is not None and 'rid="%s" ' % (self.rid) or '',
-            'xid': self.xid is not None and 'xid="%s" ' % (self.xid) or '',
-            'subs': elemstr,
+        elemstr = ", ".join(repr(elem) for elem in self.sub)
+        return "<%(class)s(%(id)s%(rid)s%(xid)s[%(subs)s])>" % {
+            "class": self.__class__.__name__,
+            "id": self.id is not None and f'id="{self.id}" ' or "",
+            "rid": self.rid is not None and f'rid="{self.rid}" ' or "",
+            "xid": self.xid is not None and f'xid="{self.xid}" ' or "",
+            "subs": elemstr,
         }
 
     def __str__(self):
         if callable(self.renderer):
             return self.renderer(self)
         if not self.isvisible:
-            return u''
-        return u''.join([six.text_type(elem) for elem in self.sub])
+            return ""
+        return "".join(str(elem) for elem in self.sub)
 
     # METHODS #
     def apply_to_strings(self, f):
-        """Apply ``f`` to all actual strings in the tree.
+        """
+        Apply ``f`` to all actual strings in the tree.
 
         :param f: Must take one (str or unicode) argument and return a
                   string or unicode.
         """
         for elem in self.flatten():
             for i in range(len(elem.sub)):
-                if isinstance(elem.sub[i], six.string_types):
+                if isinstance(elem.sub[i], str):
                     elem.sub[i] = f(elem.sub[i])
 
     def copy(self):
-        """Returns a copy of the sub-tree.  This should be overridden in
+        """
+        Returns a copy of the sub-tree.  This should be overridden in
         sub-classes with more data.
 
         .. note:: ``self.renderer`` is **not** copied.
         """
-        #logging.debug('Copying instance of class %s' % (self.__class__.__name__))
+        # logging.debug('Copying instance of class %s' % (self.__class__.__name__))
         cp = self.__class__(id=self.id, xid=self.xid, rid=self.rid)
         for sub in self.sub:
             if isinstance(sub, StringElem):
@@ -215,7 +223,8 @@ class StringElem(object):
         del parent.sub[subidx]
 
     def delete_range(self, start_index, end_index):
-        """Delete the text in the range given by the string-indexes
+        """
+        Delete the text in the range given by the string-indexes
         ``start_index`` and ``end_index``.
 
         Partial nodes will only be removed if they are editable.
@@ -230,26 +239,28 @@ class StringElem(object):
         if start_index == end_index:
             return StringElem(), self, 0
         if start_index > end_index:
-            raise IndexError('start_index > end_index: %d > %d' %
-                             (start_index, end_index))
+            raise IndexError(
+                "start_index > end_index: %d > %d" % (start_index, end_index)
+            )
         if start_index < 0 or start_index > len(self):
-            raise IndexError('start_index: %d' % (start_index))
+            raise IndexError("start_index: %d" % (start_index))
         if end_index < 1 or end_index > len(self) + 1:
-            raise IndexError('end_index: %d' % (end_index))
+            raise IndexError("end_index: %d" % (end_index))
 
         start = self.get_index_data(start_index)
-        if isinstance(start['elem'], tuple):
+        if isinstance(start["elem"], tuple):
             # If {start} is "between" elements, we use the one on the "right"
-            start['elem'] = start['elem'][-1]
-            start['offset'] = start['offset'][-1]
+            start["elem"] = start["elem"][-1]
+            start["offset"] = start["offset"][-1]
         end = self.get_index_data(end_index)
-        if isinstance(end['elem'], tuple):
+        if isinstance(end["elem"], tuple):
             # If {end} is "between" elements, we use the one on the "left"
-            end['elem'] = end['elem'][0]
-            end['offset'] = end['offset'][0]
-        assert start['elem'].isleaf() and end['elem'].isleaf()
+            end["elem"] = end["elem"][0]
+            end["offset"] = end["offset"][0]
+        assert start["elem"].isleaf()
+        assert end["elem"].isleaf()
 
-        #logging.debug('FROM %s TO %s' % (start, end))
+        # logging.debug('FROM %s TO %s' % (start, end))
 
         # Ranges can be one of 3 types:
         # 1) The entire string.
@@ -260,45 +271,48 @@ class StringElem(object):
 
         # Case 1: Entire string #
         if start_index == 0 and end_index == len(self):
-            #logging.debug('Case 1: [%s]' % (unicode(self)))
+            # logging.debug('Case 1: [%s]' % (unicode(self)))
             removed = self.copy()
             self.sub = []
             return removed, None, None
 
         # Case 2: An entire element #
-        if (start['elem'] is end['elem'] and start['offset'] == 0 and
-            end['offset'] == len(start['elem']) or
-            (not start['elem'].iseditable and start['elem'].isfragile)):
+        if (
+            start["elem"] is end["elem"]
+            and start["offset"] == 0
+            and end["offset"] == len(start["elem"])
+            or (not start["elem"].iseditable and start["elem"].isfragile)
+        ):
             ##### FOR DEBUGGING #####
-            #s = ''
-            #for e in self.flatten():
+            # s = ''
+            # for e in self.flatten():
             #    if e is start['elem']:
             #        s += '[' + unicode(e) + ']'
             #    else:
             #        s += unicode(e)
-            #logging.debug('Case 2: %s' % (s))
+            # logging.debug('Case 2: %s' % (s))
             #########################
 
-            if start['elem'] is self and self.__class__ is StringElem:
+            if start["elem"] is self and self.__class__ is StringElem:
                 removed = self.copy()
                 self.sub = []
                 return removed, None, None
-            removed = start['elem'].copy()
-            parent = self.get_parent_elem(start['elem'])
-            offset = parent.elem_offset(start['elem'])
+            removed = start["elem"].copy()
+            parent = self.get_parent_elem(start["elem"])
+            offset = parent.elem_offset(start["elem"])
             # Filter out start['elem'] below with a list comprehension in stead
             # of using parent.sub.remove(), becase list.remove() tests value
             # and not identity, which is what we want here. This ensures that
             # start['elem'] is removed and not the first element that is equal
             # to it.
-            parent.sub = [i for i in parent.sub if i is not start['elem']]
+            parent.sub = [i for i in parent.sub if i is not start["elem"]]
             return removed, parent, offset
 
         # Case 3: Within a single element #
-        if start['elem'] is end['elem'] and start['elem'].iseditable:
+        if start["elem"] is end["elem"] and start["elem"].iseditable:
             ##### FOR DEBUGGING #####
-            #s = ''
-            #for e in self.flatten():
+            # s = ''
+            # for e in self.flatten():
             #    if e is start['elem']:
             #        s += '%s[%s]%s' % (
             #            e[:start['offset']],
@@ -307,81 +321,81 @@ class StringElem(object):
             #        )
             #    else:
             #        s += unicode(e)
-            #logging.debug('Case 3: %s' % (s))
+            # logging.debug('Case 3: %s' % (s))
             #########################
 
             # XXX: This might not have the expected result if start['elem']
             # is a StringElem sub-class instance.
-            newstr = u''.join(start['elem'].sub)
-            removed = StringElem(newstr[start['offset']:end['offset']])
-            newstr = newstr[:start['offset']] + newstr[end['offset']:]
-            parent = self.get_parent_elem(start['elem'])
-            if parent is None and start['elem'] is self:
+            newstr = "".join(start["elem"].sub)
+            removed = StringElem(newstr[start["offset"] : end["offset"]])
+            newstr = newstr[: start["offset"]] + newstr[end["offset"] :]
+            parent = self.get_parent_elem(start["elem"])
+            if parent is None and start["elem"] is self:
                 parent = self
-            start['elem'].sub = [newstr]
+            start["elem"].sub = [newstr]
             self.prune()
-            return removed, start['elem'], start['offset']
+            return removed, start["elem"], start["offset"]
 
         # Case 4: Across multiple elements #
         range_nodes = self.depth_first()
         startidx = 0
         endidx = -1
         for i in range(len(range_nodes)):
-            if range_nodes[i] is start['elem']:
+            if range_nodes[i] is start["elem"]:
                 startidx = i
-            elif range_nodes[i] is end['elem']:
+            elif range_nodes[i] is end["elem"]:
                 endidx = i
                 break
-        range_nodes = range_nodes[startidx:endidx+1]
-        #assert (range_nodes[0] is start['elem'] and
+        range_nodes = range_nodes[startidx : endidx + 1]
+        # assert (range_nodes[0] is start['elem'] and
         #        range_nodes[-1] is end['elem'])
-        #logging.debug("Nodes in delete range: %s" % (str(range_nodes)))
+        # logging.debug("Nodes in delete range: %s" % (str(range_nodes)))
 
         marked_nodes = []  # Contains nodes that have been marked for deletion (directly or inderectly (via parent)).
         for node in range_nodes[1:-1]:
             if [n for n in marked_nodes if n is node]:
                 continue
             subtree = node.depth_first()
-            if not [e for e in subtree if e is end['elem']]:
-                #logging.debug("Marking node: %s" % (subtree))
+            if not [e for e in subtree if e is end["elem"]]:
+                # logging.debug("Marking node: %s" % (subtree))
                 marked_nodes.extend(subtree)  # "subtree" does not include "node"
 
         ##### FOR DEBUGGING #####
-        #s = ''
-        #for e in self.flatten():
+        # s = ''
+        # for e in self.flatten():
         #    if e is start['elem']:
         #        s += '%s[%s' % (e[:start['offset']], e[start['offset']:])
         #    elif e is end['elem']:
         #        s += '%s]%s' % (e[:end['offset']], e[end['offset']:])
         #    else:
         #        s += unicode(e)
-        #logging.debug('Case 4: %s' % (s))
+        # logging.debug('Case 4: %s' % (s))
         #########################
 
         removed = self.copy()
 
         # Save offsets before we start changing the tree
-        start_offset = self.elem_offset(start['elem'])
-        end_offset = self.elem_offset(end['elem'])
+        start_offset = self.elem_offset(start["elem"])
+        end_offset = self.elem_offset(end["elem"])
 
         for node in marked_nodes:
-            try:
+            with contextlib.suppress(ElementNotFoundError):
                 self.delete_elem(node)
-            except ElementNotFoundError as e:
-                pass
 
-        if start['elem'] is not end['elem']:
-            if (start_offset == start['index'] or
-                (not start['elem'].iseditable and start['elem'].isfragile)):
-                self.delete_elem(start['elem'])
-            elif start['elem'].iseditable:
-                start['elem'].sub = [u''.join(start['elem'].sub)[:start['offset']]]
+        if start["elem"] is not end["elem"]:
+            if start_offset == start["index"] or (
+                not start["elem"].iseditable and start["elem"].isfragile
+            ):
+                self.delete_elem(start["elem"])
+            elif start["elem"].iseditable:
+                start["elem"].sub = ["".join(start["elem"].sub)[: start["offset"]]]
 
-            if (end_offset + len(end['elem']) == end['index'] or
-                (not end['elem'].iseditable and end['elem'].isfragile)):
-                self.delete_elem(end['elem'])
-            elif end['elem'].iseditable:
-                end['elem'].sub = [u''.join(end['elem'].sub)[end['offset']:]]
+            if end_offset + len(end["elem"]) == end["index"] or (
+                not end["elem"].iseditable and end["elem"].isfragile
+            ):
+                self.delete_elem(end["elem"])
+            elif end["elem"].iseditable:
+                end["elem"].sub = ["".join(end["elem"].sub)[end["offset"] :]]
 
         self.prune()
         return removed, None, None
@@ -389,7 +403,7 @@ class StringElem(object):
     def depth_first(self, filter=None):
         """Returns a list of the nodes in the tree in depth-first order."""
         if filter is None or not callable(filter):
-            filter = lambda e: True
+            filter = filter_all
         elems = []
         if filter(self):
             elems.append(self)
@@ -403,12 +417,13 @@ class StringElem(object):
                 elems.extend(sub.depth_first(filter))
         return elems
 
-    def encode(self, encoding=sys.getdefaultencoding()):
+    def encode(self, encoding="utf-8"):
         """More ``unicode`` class emulation."""
-        return six.text_type(self).encode(encoding)
+        return str(self).encode(encoding)
 
     def elem_offset(self, elem):
-        """Find the offset of ``elem`` in the current tree.
+        """
+        Find the offset of ``elem`` in the current tree.
 
         This cannot be reliably used if ``self.renderer`` is used and even
         less so if the rendering function renders the string differently
@@ -432,15 +447,15 @@ class StringElem(object):
             if e.isleaf():
                 leafoffset = 0
                 for s in e.sub:
-                    if six.text_type(s) == six.text_type(elem):
+                    if str(s) == str(elem):
                         return offset + leafoffset
-                    else:
-                        leafoffset += len(six.text_type(s))
+                    leafoffset += len(str(s))
                 offset += len(e)
         return -1
 
     def elem_at_offset(self, offset):
-        """Get the ``StringElem`` in the tree that contains the string rendered
+        """
+        Get the ``StringElem`` in the tree that contains the string rendered
         at the given offset.
         """
         if offset < 0 or offset > len(self):
@@ -456,26 +471,28 @@ class StringElem(object):
         return elem
 
     def find(self, x):
-        """Find sub-string ``x`` in this string tree and return the position at
+        """
+        Find sub-string ``x`` in this string tree and return the position at
         which it starts.
         """
-        if isinstance(x, six.string_types):
-            return six.text_type(self).find(x)
+        if isinstance(x, str):
+            return str(self).find(x)
         if isinstance(x, StringElem):
-            return six.text_type(self).find(six.text_type(x))
+            return str(self).find(str(x))
         return None
 
     def find_elems_with(self, x):
         """Find all elements in the current sub-tree containing ``x``."""
-        return [elem for elem in self.flatten() if x in six.text_type(elem)]
+        return [elem for elem in self.flatten() if x in str(elem)]
 
     def flatten(self, filter=None):
-        """Flatten the tree by returning a depth-first search over the tree's
+        """
+        Flatten the tree by returning a depth-first search over the tree's
         leaves.
         """
         if filter is None or not callable(filter):
-            filter = lambda e: True
-        return [elem for elem in self.iter_depth_first(lambda e: e.isleaf() and filter(e))]
+            filter = filter_all
+        return list(self.iter_depth_first(lambda e: e.isleaf() and filter(e)))
 
     def get_ancestor_where(self, child, criteria):
         parent = self.get_parent_elem(child)
@@ -484,7 +501,8 @@ class StringElem(object):
         return self.get_ancestor_where(parent, criteria)
 
     def get_index_data(self, index):
-        """Get info about the specified range in the tree.
+        """
+        Get info about the specified range in the tree.
 
         :returns: A dictionary with the following items:
 
@@ -493,21 +511,22 @@ class StringElem(object):
            - *offset*: The offset of ``index`` into ``'elem'``.
         """
         info = {
-            'elem': self.elem_at_offset(index),
-            'index': index,
+            "elem": self.elem_at_offset(index),
+            "index": index,
         }
-        info['offset'] = info['index'] - self.elem_offset(info['elem'])
+        info["offset"] = info["index"] - self.elem_offset(info["elem"])
 
         # Check if there "index" is actually between elements
         leftelem = self.elem_at_offset(index - 1)
-        if leftelem is not None and leftelem is not info['elem']:
-            info['elem'] = (leftelem, info['elem'])
-            info['offset'] = (len(leftelem), 0)
+        if leftelem is not None and leftelem is not info["elem"]:
+            info["elem"] = (leftelem, info["elem"])
+            info["offset"] = (len(leftelem), 0)
 
         return info
 
     def get_parent_elem(self, child):
-        """Searches the current sub-tree for and returns the parent of the
+        """
+        Searches the current sub-tree for and returns the parent of the
         ``child`` element.
         """
         for elem in self.iter_depth_first():
@@ -519,19 +538,20 @@ class StringElem(object):
         return None
 
     def insert(self, offset, text, preferred_parent=None):
-        """Insert the given text at the specified offset of this string-tree's
+        """
+        Insert the given text at the specified offset of this string-tree's
         string (Unicode) representation.
         """
         if offset < 0 or offset > len(self):
-            raise IndexError('Index out of range: %d' % (offset))
-        if isinstance(text, six.string_types):
+            raise IndexError("Index out of range: %d" % (offset))
+        if isinstance(text, str):
             text = StringElem(text)
         if not isinstance(text, StringElem):
-            raise ValueError('text must be of type StringElem')
+            raise TypeError("text must be of type StringElem")
 
         def checkleaf(elem, text):
             if elem.isleaf() and type(text) is StringElem and text.isleaf():
-                return six.text_type(text)
+                return str(text)
             return text
 
         # There are 4 general cases (including specific cases) where text can
@@ -553,27 +573,24 @@ class StringElem(object):
         if offset == 0:
             # 1.1 #
             if oelem.iseditable:
-                #logging.debug('Case 1.1')
+                # logging.debug('Case 1.1')
                 oelem.sub.insert(0, checkleaf(oelem, text))
                 oelem.prune()
                 return True
             # 1.2 #
-            else:
-                #logging.debug('Case 1.2')
-                oparent = self.get_ancestor_where(oelem, lambda x: x.iseditable)
-                if oparent is not None:
-                    oparent.sub.insert(0, checkleaf(oparent, text))
-                    return True
-                else:
-                    self.sub.insert(0, checkleaf(self, text))
-                    return True
-            return False
+            # logging.debug('Case 1.2')
+            oparent = self.get_ancestor_where(oelem, filter_editable)
+            if oparent is not None:
+                oparent.sub.insert(0, checkleaf(oparent, text))
+                return True
+            self.sub.insert(0, checkleaf(self, text))
+            return True
 
         # Case 2 #
         if offset == len(self):
-            #logging.debug('Case 2')
+            # logging.debug('Case 2')
             last = self.flatten()[-1]
-            parent = self.get_ancestor_where(last, lambda x: x.iseditable)
+            parent = self.get_ancestor_where(last, filter_editable)
             if parent is None:
                 parent = self
             preferred_type = type(preferred_parent)
@@ -582,7 +599,7 @@ class StringElem(object):
             if preferred_parent is oelem:
                 # The preferred parent is still in this StringElem
                 return oelem.insert(len_oelem, text)
-            elif oelem_type == preferred_type:
+            if oelem_type == preferred_type:
                 # oelem has the right type
                 return oelem.insert(len_oelem, text)
 
@@ -594,25 +611,24 @@ class StringElem(object):
         # Case 3 #
         if oelem is before:
             if oelem.iseditable:
-                #logging.debug('Case 3')
+                # logging.debug('Case 3')
                 eoffset = offset - self.elem_offset(oelem)
                 if oelem.isleaf():
-                    s = six.text_type(oelem)  # Collapse all sibling strings into one
+                    s = str(oelem)  # Collapse all sibling strings into one
                     head = s[:eoffset]
                     tail = s[eoffset:]
                     if type(text) is StringElem and text.isleaf():
-                        oelem.sub = [head + six.text_type(text) + tail]
+                        oelem.sub = [head + str(text) + tail]
                     else:
                         oelem.sub = [StringElem(head), text, StringElem(tail)]
                     return True
-                else:
-                    return oelem.insert(eoffset, text)
+                return oelem.insert(eoffset, text)
             return False
 
         # And the only case left: Case 4 #
         # 4.1 #
         if not before.iseditable and not oelem.iseditable:
-            #logging.debug('Case 4.1')
+            # logging.debug('Case 4.1')
             # Neither are editable, so we add it as a sibling (to the right)
             # of before
             bparent = self.get_parent_elem(before)
@@ -631,8 +647,8 @@ class StringElem(object):
             return True
 
         # 4.2 #
-        elif before.iseditable and oelem.iseditable:
-            #logging.debug('Case 4.2')
+        if before.iseditable and oelem.iseditable:
+            # logging.debug('Case 4.2')
             # We can add to either, but we try hard to add to the correct one
             # so that we avoid inserting text in the wrong place on undo, for
             # example.
@@ -642,10 +658,10 @@ class StringElem(object):
             if preferred_parent is oelem:
                 # The preferred parent is still in this StringElem
                 return oelem.insert(0, text)
-            elif oelem_type == preferred_type and not before_type == preferred_type:
+            if oelem_type == preferred_type and before_type != preferred_type:
                 # oelem has the right type and before has the wrong type
                 return oelem.insert(0, text)
-            elif oelem_type != preferred_type and before_type != preferred_type:
+            if preferred_type not in (oelem_type, before_type):
                 # Both are the wrong type, so we add it as if neither were
                 # editable
                 bparent = self.get_parent_elem(before)
@@ -661,13 +677,13 @@ class StringElem(object):
             return before.insert(len(before), text)  # Reinterpret as a case 2
 
         # 4.3 #
-        elif before.iseditable and not oelem.iseditable:
-            #logging.debug('Case 4.3')
+        if before.iseditable and not oelem.iseditable:
+            # logging.debug('Case 4.3')
             return before.insert(len(before), text)  # Reinterpret as a case 2
 
         # 4.4 #
-        elif not before.iseditable and oelem.iseditable:
-            #logging.debug('Case 4.4')
+        if not before.iseditable and oelem.iseditable:
+            # logging.debug('Case 4.4')
             return oelem.insert(0, text)  # Reinterpret as a case 1
 
         return False
@@ -684,14 +700,16 @@ class StringElem(object):
                 # element ("left is right"), if it has any other content.
                 # If an element has content, it will be at least directly
                 # left or directly right of the current cursor position.
-                raise ValueError('"left" and "right" refer to the same element and is not empty.')
+                raise ValueError(
+                    '"left" and "right" refer to the same element and is not empty.'
+                )
             if not left.iseditable:
                 return False
-        if isinstance(text, six.text_type):
+        if isinstance(text, str):
             text = StringElem(text)
 
         if left is right:
-            #logging.debug('left%s.sub.append(%s)' % (repr(left), repr(text)))
+            # logging.debug('left%s.sub.append(%s)' % (repr(left), repr(text)))
             left.sub.append(text)
             return True
         # XXX: The "in" keyword is *not* used below, because the "in" tests
@@ -700,13 +718,13 @@ class StringElem(object):
 
         if left is None:
             if self is right:
-                #logging.debug('self%s.sub.insert(0, %s)' %
+                # logging.debug('self%s.sub.insert(0, %s)' %
                 #              (repr(self), repr(text)))
                 self.sub.insert(0, text)
                 return True
             parent = self.get_parent_elem(right)
             if parent is not None:
-                #logging.debug('parent%s.sub.insert(0, %s)' %
+                # logging.debug('parent%s.sub.insert(0, %s)' %
                 #              (repr(parent), repr(text)))
                 parent.sub.insert(0, text)
                 return True
@@ -714,13 +732,13 @@ class StringElem(object):
 
         if right is None:
             if self is left:
-                #logging.debug('self%s.sub.append(%s)' %
+                # logging.debug('self%s.sub.append(%s)' %
                 #              (repr(self), repr(text)))
                 self.sub.append(text)
                 return True
             parent = self.get_parent_elem(left)
             if parent is not None:
-                #logging.debug('parent%s.sub.append(%s)' %
+                # logging.debug('parent%s.sub.append(%s)' %
                 #              (repr(parent), repr(text)))
                 parent.sub.append(text)
                 return True
@@ -735,7 +753,7 @@ class StringElem(object):
                 ischild = True
                 break
         if ischild:
-            #logging.debug('left%s.sub.insert(0, %s)' %
+            # logging.debug('left%s.sub.insert(0, %s)' %
             #              (repr(left), repr(text)))
             left.sub.insert(0, text)
             return True
@@ -746,7 +764,7 @@ class StringElem(object):
                 ischild = True
                 break
         if ischild:
-            #logging.debug('right%s.sub.append(%s)' %
+            # logging.debug('right%s.sub.append(%s)' %
             #              (repr(right), repr(text)))
             right.sub.append(text)
             return True
@@ -758,7 +776,7 @@ class StringElem(object):
                 if child is left:
                     break
                 idx += 1
-            #logging.debug('parent%s.sub.insert(%d, %s)' %
+            # logging.debug('parent%s.sub.insert(%d, %s)' %
             #              (repr(parent), idx, repr(text)))
             parent.sub.insert(idx, text)
             return True
@@ -770,13 +788,12 @@ class StringElem(object):
                 if child is right:
                     break
                 idx += 1
-            #logging.debug('parent%s.sub.insert(%d, %s)' %
+            # logging.debug('parent%s.sub.insert(%d, %s)' %
             #              (repr(parent), idx, repr(text)))
             parent.sub.insert(0, text)
             return True
 
-        logging.debug('Could not insert between %s and %s... odd.' %
-                      (repr(left), repr(right)))
+        logging.debug("Could not insert between %r and %r... odd.", left, right)
         return False
 
     def isleaf(self):
@@ -788,15 +805,12 @@ class StringElem(object):
 
         :rtype: bool
         """
-        for e in self.sub:
-            if not isinstance(e, six.string_types):
-                return False
-        return True
+        return all(isinstance(e, str) for e in self.sub)
 
     def iter_depth_first(self, filter=None):
         """Iterate through the nodes in the tree in dept-first order."""
         if filter is None or not callable(filter):
-            filter = lambda e: True
+            filter = filter_all
         if filter(self):
             yield self
         for sub in self.sub:
@@ -805,17 +819,17 @@ class StringElem(object):
             if sub.isleaf() and filter(sub):
                 yield sub
             else:
-                for node in sub.iter_depth_first(filter):
-                    yield node
+                yield from sub.iter_depth_first(filter)
 
     def map(self, f, filter=None):
-        """Apply ``f`` to all nodes for which ``filter`` returned ``True``
+        """
+        Apply ``f`` to all nodes for which ``filter`` returned ``True``
         (optional).
         """
         if filter is not None and not callable(filter):
-            raise ValueError('filter is not callable or None')
+            raise ValueError("filter is not callable or None")
         if filter is None:
-            filter = lambda e: True
+            filter = filter_all
 
         for elem in self.depth_first():
             if filter(elem):
@@ -823,7 +837,8 @@ class StringElem(object):
 
     @classmethod
     def parse(cls, pstr):
-        """Parse an instance of this class from the start of the given string.
+        """
+        Parse an instance of this class from the start of the given string.
         This method should be implemented by any sub-class that wants to
         parseable by :mod:`translate.storage.placeables.parse`.
 
@@ -835,14 +850,14 @@ class StringElem(object):
         return cls(pstr)
 
     def print_tree(self, indent=0, verbose=False):
-        """Print the tree from the current instance's point in an indented
+        """
+        Print the tree from the current instance's point in an indented
         manner.
         """
         indent_prefix = " " * indent * 2
-        out = (u"%s%s [%s]" % (indent_prefix, self.__class__.__name__,
-                               six.text_type(self))).encode('utf-8')
+        out = f"{indent_prefix}{self.__class__.__name__} [{self!s}]"
         if verbose:
-            out += u' ' + repr(self)
+            out += " " + repr(self)
 
         print(out)
 
@@ -850,8 +865,7 @@ class StringElem(object):
             if isinstance(elem, StringElem):
                 elem.print_tree(indent + 1, verbose=verbose)
             else:
-                print((u'%s%s[%s]' % (indent_prefix, indent_prefix,
-                                      elem)).encode('utf-8'))
+                print(f"{indent_prefix}{indent_prefix}[{elem}]")
 
     def prune(self):
         """Remove unnecessary nodes to make the tree optimal."""
@@ -874,9 +888,11 @@ class StringElem(object):
                 # Symbolically: StringElem->X(leaf) => X(leaf)
                 #   (where X is any sub-class of StringElem,
                 #   but not StringElem)
-                if (type(elem) is StringElem and
-                    isinstance(child, StringElem) and
-                    type(child) is not StringElem):
+                if (
+                    type(elem) is StringElem
+                    and isinstance(child, StringElem)
+                    and type(child) is not StringElem
+                ):
                     parent = self.get_parent_elem(elem)
                     if parent is not None:
                         parent.sub[parent.sub.index(elem)] = child
@@ -884,18 +900,19 @@ class StringElem(object):
 
             if type(elem) is StringElem and elem.isleaf():
                 # Collapse all strings in this leaf into one string.
-                elem.sub = [u''.join(elem.sub)]
+                elem.sub = ["".join(elem.sub)]
 
             for i in reversed(range(len(elem.sub))):
                 # Remove empty strings or StringElem nodes
                 # (but not StringElem sub-class instances, because they
                 # might contain important (non-rendered) data.
-                if ((type(elem.sub[i]) == StringElem or isinstance(elem.sub[i], six.string_types)) and
-                    len(elem.sub[i]) == 0):
+                if (
+                    type(elem.sub[i]) is StringElem or isinstance(elem.sub[i], str)
+                ) and len(elem.sub[i]) == 0:
                     del elem.sub[i]
                     continue
 
-                if isinstance(elem.sub[i], six.string_types) and not elem.isleaf():
+                if isinstance(elem.sub[i], str) and not elem.isleaf():
                     elem.sub[i] = StringElem(elem.sub[i])
                     changed = True
 
@@ -907,13 +924,12 @@ class StringElem(object):
 
                     for i in range(len(elem.sub) - 1):
                         lsub = elem.sub[i]
-                        rsub = elem.sub[i+1]
+                        rsub = elem.sub[i + 1]
 
-                        if (type(lsub) is StringElem and
-                            type(rsub) is StringElem):
+                        if type(lsub) is StringElem and type(rsub) is StringElem:
                             changed = True
                             lsub.sub.extend(rsub.sub)
-                            del elem.sub[i+1]
+                            del elem.sub[i + 1]
                             leafchanged = True
                             break
 
@@ -925,7 +941,8 @@ class StringElem(object):
 
     # TODO: Write unit test for this method
     def remove_type(self, ptype):
-        r"""Replace nodes with type ``ptype`` with base ``StringElem``\s,
+        r"""
+        Replace nodes with type ``ptype`` with base ``StringElem``\s,
         containing the same sub-elements. This is only applicable to elements
         below the element tree root node.
         """
@@ -941,7 +958,8 @@ class StringElem(object):
                 )
 
     def translate(self):
-        """Transform the sub-tree according to some class-specific needs.  This
+        """
+        Transform the sub-tree according to some class-specific needs.  This
         method should be either overridden in implementing sub-classes or
         dynamically replaced by specific applications.
 
